@@ -7,6 +7,7 @@ import sys
 
 SUPPORTED_FILE_EXTENSIONS = [".jpg", ".jpeg", ".png", ".bmp"]
 
+
 def _bytes_to_mega_bytes(bytes: int) -> float:
     return bytes / 1024 / 1024
 
@@ -23,7 +24,8 @@ def _scale(img: pathlib.Path, scale: float) -> pathlib.Path:
     result = img.parent / out_name
     try:
         output = subprocess.check_output(
-            f'ffmpeg -i "{img}" -vf scale="iw/{as_divisor:.2f}:-1" "{result}"', stderr=subprocess.STDOUT
+            f'ffmpeg -i "{img}" -vf scale="iw/{as_divisor:.2f}:-1" "{result}"',
+            stderr=subprocess.STDOUT,
         )
     except subprocess.CalledProcessError:
         print(output, file=sys.stderr)
